:orphan:

Flask-RESTful
=============

.. module:: flask_restful

**Flask-RESTful** is an extension for Flask that adds support for quickly
building REST APIs.  It is a lightweight abstraction that works with your
existing ORM/libraries.  Flask-RESTful encourages best practices with minimal
setup. If you are familiar with Flask, Flask-RESTful should be easy to pick up.

.. include:: contents.rst.inc
